@@ -31,12 +31,13 @@ $VAR1 = {
                        'town' => 'Berlin',
                        'msn' => '',
                        'jahoo' => '',
-                       'email' => 'dirk.lindner(a)gmx.de',
+                       'email' => 'lzer(a)cpan.org',
                        'icq' => '350108541',
+                       'password' => 'testpass',
                        'tel' => '',
                        'postcode' => '10965',
                        'country' => 'Deutschland',
-                       'name' => 'Musterman',
+                       'name' => 'Lindner',
                        'tonwn' => 'Berlin',
                        'aim' => '',
                        'signature' => 'perl -e\'&{sub{s~~shift~e;s-(&*{*{*#*L*.Z*.E*.)-chr-eg;print}}(100105114107)\'',
@@ -44,7 +45,7 @@ $VAR1 = {
                        'jabber' => ''
                      },
           'language' => 'en',
-          'version' => '0.43',
+          'version' => '0.44',
           'cgi' => {
                      'bin' => '/srv/www/cgi-bin',
                      'style' => 'lze',
