@@ -66,7 +66,7 @@ $VAR1 = {
         'export'               => 'Export',
         'savefile'             => 'Explorer',
         'haveacount'           => 'You already have an Acount',
-        'links'                => 'Bookmarks',
+        'links'                => 'Sitemap',
         'savetreeviewentry'    => 'TreeView',
         'newindex'             => 'New Index',
         'admin'                => 'Admin',
@@ -108,7 +108,7 @@ $VAR1 = {
         'indexover'            => 'Indexover',
         'optimize'             => 'Optimize',
         'execsql'              => 'Exec Sql',
-        'news'                 => 'News',
+        'news'                 => 'Logbook',
         'headline'             => 'Headline',
         'rights'               => 'Rights',
         'edit entry'           => 'Edit Entry',
@@ -142,7 +142,7 @@ $VAR1 = {
         'referer'                  => 'Referer',
         'create'                   => 'Create',
         'choosefile'               => 'Choose Attachment',
-        'edit links'               => 'Edit links',
+        'edit links'               => 'Edit Sitemap',
         'shownewentry'             => 'New Entry',
         'deleteentry'              => 'Delete Entry',
         'env'                      => 'Env',
@@ -188,7 +188,7 @@ $VAR1 = {
         'gbook'                    => 'Gbook',
         'dumptable'                => 'Databases',
         'databases'                => 'Databases',
-        'blog'                     => 'News',
+        'blog'                     => 'Logbook',
         'settings'                 => 'Settings',
         'seq_in_index'             => 'Seq_in_index',
         'reply'                    => 'Replies',
@@ -198,7 +198,10 @@ $VAR1 = {
         'newmessage'               => 'New Topic',
         'showwindow'               => 'Show Windows',
         'changeengine'             => 'Change Engine',
-        'connect'                  => 'Connect'
+        'createdatabase'           => 'New Database',
+        'showdatabases'            => 'Databases',
+        'connect'                  => 'Connect',
+        'DropDatabase'             => 'Drop Database',
     },
     'de' => {
         'insert'              => 'Einf&#252;gen',
@@ -231,7 +234,7 @@ $VAR1 = {
         'translate'               => '&#220;bersetzen',
         'showrights'              => 'Datenbank',
         'editvmenu'               => 'Vertikales Menu',
-        'delete'                  => 'Lschen',
+        'delete'                  => 'L&#246;schen',
         'chars'                   => 'Zeichen &#252;brig:',
         'sitemap'                 => '&#252;bersicht',
         'links_pro_page'          => 'Eintr&auml;ge/Seite',
@@ -273,7 +276,7 @@ $VAR1 = {
         'export'               => 'Exportieren',
         'haveacount'           => 'Sie haben bereits einen Acount',
         'savetreeviewentry'    => 'TreeView',
-        'links'                => 'Lesezeichen',
+        'links'                => 'Sitemap',
         'newindex'             => 'Neuer Index',
         'failed: invalid code' => 'Fehler: falscher Captcha Code',
         'admin'                => 'Administrator',
@@ -313,7 +316,7 @@ $VAR1 = {
         'permission denied'    => 'Keine Berechtigung',
         'indexover'            => 'Index &#252;ber',
         'optimize'             => 'Optimieren',
-        'news'                 => 'Neues',
+        'news'                 => 'Logbook',
         'execsql'              => 'Sql ausf&uuml;hren',
         'headline'             => '&#220;berschrift',
         'rights'               => 'Rechte',
@@ -332,7 +335,7 @@ $VAR1 = {
         'edittree'                 => 'Bearbeiten',
         'username'                 => 'Benutzer',
         'createtable'              => 'Tabelle erstellen',
-        'deletetreeviewentry'      => 'Lsche',
+        'deletetreeviewentry'      => 'Lösche',
         'showusers'                => 'Benutzer Anzeigen',
         'changeautoincrementvalue' => 'autoincrement wert &#228;ndern',
         'showtable'                => 'Tabelle Anzeigen',
@@ -350,7 +353,7 @@ $VAR1 = {
         'editfile'                 => 'Datei bearbeiten',
         'newfileadded'             => 'Neue Datei wurde erstellt',
         'referer'                  => 'Referer',
-        'edit links'               => 'Lesezeichen bearbeiten',
+        'edit links'               => 'Sitemap bearbeiten',
         'create'                   => 'Erstellen',
         'choosefile'               => 'File ausw&#228;hlen',
         'shownewentry'             => 'Neuer Eintrag',
@@ -410,8 +413,10 @@ $VAR1 = {
         'showwindow'     => 'Fenster anzeigen',
         'newmessage'     => 'Neue Nachricht',
         'changeengine'   => 'Engine &#228;ndern',
-        'connect'        => 'Verbinden'
-
+        'showdatabases'  => 'Datenbanken',
+        'createdatabase' => 'Neue Datenbank',
+        'connect'        => 'Verbinden',
+        'DropDatabase'   => 'Datenbank löschen',
     }
 };
 $lang = $VAR1;
